@@ -15,7 +15,7 @@
 #include "actions/actions.h"
 #include "triggers/triggers.h"
 
-#include "QtCore/QList"
+#include "QList"
 
 #include "kdemacros.h"
 
@@ -60,7 +60,7 @@ class Q_DECL_EXPORT ActionDataGroup
             ActionDataGroup* parent_P,
             const QString& name_P = QString(),
             const QString& comment_P = QString(),
-            Condition_list* conditions_P = NULL,
+            Condition_list* conditions_P = nullptr,
             system_group_t system_group_P = SYSTEM_NONE);
 
         virtual ~ActionDataGroup();
@@ -89,7 +89,7 @@ class Q_DECL_EXPORT ActionDataGroup
         const QList<ActionDataBase*> children() const;
 
         /**
-         * Number of childrens.
+         * Number of children.
          */
         int size() const;
 
